# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: smq.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'smq.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tsmq.proto\x12\x03smq\"3\n\x10RetrievedMessage\x12\x0f\n\x07message\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\x03\"I\n\x13\x42ulkRetrieveRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x14\n\x0cstart_offset\x18\x02 \x01(\x03\x12\r\n\x05limit\x18\x03 \x01(\x05\"c\n\x14\x42ulkRetrieveResponse\x12\'\n\x08messages\x18\x01 \x03(\x0b\x32\x15.smq.RetrievedMessage\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x13\n\x0bnext_offset\x18\x03 \x01(\x03\"\x10\n\x0e\x43onnectRequest\"\x11\n\x0f\x43onnectResponse\"\'\n\x16GetLatestOffsetRequest\x12\r\n\x05topic\x18\x01 \x01(\t\")\n\x17GetLatestOffsetResponse\x12\x0e\n\x06offset\x18\x01 \x01(\x03\")\n\x18GetEarliestOffsetRequest\x12\r\n\x05topic\x18\x01 \x01(\t\"+\n\x19GetEarliestOffsetResponse\x12\x0e\n\x06offset\x18\x01 \x01(\x03\"#\n\x12\x43reateTopicRequest\x12\r\n\x05topic\x18\x01 \x01(\t\"\x15\n\x13\x43reateTopicResponse\"0\n\x0eProduceRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\x0c\"!\n\x0fProduceResponse\x12\x0e\n\x06offset\x18\x01 \x01(\x03\"/\n\x0e\x43onsumeRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x03\"2\n\x0f\x43onsumeResponse\x12\x0f\n\x07message\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\x03\"9\n\x18\x44\x65leteUntilOffsetRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x03\"\x1b\n\x19\x44\x65leteUntilOffsetResponse2\xc3\x05\n\x12SuhaibMessageQueue\x12\x36\n\x07\x43onnect\x12\x13.smq.ConnectRequest\x1a\x14.smq.ConnectResponse\"\x00\x12N\n\x0fGetLatestOffset\x12\x1b.smq.GetLatestOffsetRequest\x1a\x1c.smq.GetLatestOffsetResponse\"\x00\x12T\n\x11GetEarliestOffset\x12\x1d.smq.GetEarliestOffsetRequest\x1a\x1e.smq.GetEarliestOffsetResponse\"\x00\x12\x42\n\x0b\x43reateTopic\x12\x17.smq.CreateTopicRequest\x1a\x18.smq.CreateTopicResponse\"\x00\x12\x36\n\x07Produce\x12\x13.smq.ProduceRequest\x1a\x14.smq.ProduceResponse\"\x00\x12\x36\n\x07\x43onsume\x12\x13.smq.ConsumeRequest\x1a\x14.smq.ConsumeResponse\"\x00\x12>\n\rStreamProduce\x12\x13.smq.ProduceRequest\x1a\x14.smq.ProduceResponse\"\x00(\x01\x12>\n\rStreamConsume\x12\x13.smq.ConsumeRequest\x1a\x14.smq.ConsumeResponse\"\x00\x30\x01\x12T\n\x11\x44\x65leteUntilOffset\x12\x1d.smq.DeleteUntilOffsetRequest\x1a\x1e.smq.DeleteUntilOffsetResponse\"\x00\x12\x45\n\x0c\x42ulkRetrieve\x12\x18.smq.BulkRetrieveRequest\x1a\x19.smq.BulkRetrieveResponse\"\x00\x42\tZ\x07./protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'smq_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\007./proto'
  _globals['_RETRIEVEDMESSAGE']._serialized_start=18
  _globals['_RETRIEVEDMESSAGE']._serialized_end=69
  _globals['_BULKRETRIEVEREQUEST']._serialized_start=71
  _globals['_BULKRETRIEVEREQUEST']._serialized_end=144
  _globals['_BULKRETRIEVERESPONSE']._serialized_start=146
  _globals['_BULKRETRIEVERESPONSE']._serialized_end=245
  _globals['_CONNECTREQUEST']._serialized_start=247
  _globals['_CONNECTREQUEST']._serialized_end=263
  _globals['_CONNECTRESPONSE']._serialized_start=265
  _globals['_CONNECTRESPONSE']._serialized_end=282
  _globals['_GETLATESTOFFSETREQUEST']._serialized_start=284
  _globals['_GETLATESTOFFSETREQUEST']._serialized_end=323
  _globals['_GETLATESTOFFSETRESPONSE']._serialized_start=325
  _globals['_GETLATESTOFFSETRESPONSE']._serialized_end=366
  _globals['_GETEARLIESTOFFSETREQUEST']._serialized_start=368
  _globals['_GETEARLIESTOFFSETREQUEST']._serialized_end=409
  _globals['_GETEARLIESTOFFSETRESPONSE']._serialized_start=411
  _globals['_GETEARLIESTOFFSETRESPONSE']._serialized_end=454
  _globals['_CREATETOPICREQUEST']._serialized_start=456
  _globals['_CREATETOPICREQUEST']._serialized_end=491
  _globals['_CREATETOPICRESPONSE']._serialized_start=493
  _globals['_CREATETOPICRESPONSE']._serialized_end=514
  _globals['_PRODUCEREQUEST']._serialized_start=516
  _globals['_PRODUCEREQUEST']._serialized_end=564
  _globals['_PRODUCERESPONSE']._serialized_start=566
  _globals['_PRODUCERESPONSE']._serialized_end=599
  _globals['_CONSUMEREQUEST']._serialized_start=601
  _globals['_CONSUMEREQUEST']._serialized_end=648
  _globals['_CONSUMERESPONSE']._serialized_start=650
  _globals['_CONSUMERESPONSE']._serialized_end=700
  _globals['_DELETEUNTILOFFSETREQUEST']._serialized_start=702
  _globals['_DELETEUNTILOFFSETREQUEST']._serialized_end=759
  _globals['_DELETEUNTILOFFSETRESPONSE']._serialized_start=761
  _globals['_DELETEUNTILOFFSETRESPONSE']._serialized_end=788
  _globals['_SUHAIBMESSAGEQUEUE']._serialized_start=791
  _globals['_SUHAIBMESSAGEQUEUE']._serialized_end=1498
# @@protoc_insertion_point(module_scope)
